/***************************************************************************
                          ann_w_static.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_w_static.h>

  //                //
 // class W_static //
//                //

ANN::W_static::~W_static()
{
}

void
ANN::W_static::feed_back(const Term &d_)
{
}

void
ANN::W_static::commit(NE &ne)
{
}

void
ANN::W_static::randomize()
{
}

